package com.ruoyi.yh.reportProd.domain;

import com.ruoyi.common.annotation.Excel;
import com.ruoyi.common.constant.DictType;
import com.ruoyi.common.core.domain.BaseEntity;
import com.ruoyi.system.valid.DictValid;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.math.BigDecimal;

/**
 * 报表产量对象 bst_report_prod
 *
 * @author ruoyi
 * @date 2024-10-31
 */
@Data
public class ReportProd extends BaseEntity
{
    private static final long serialVersionUID = 1L;

    @Excel(name = "编号")
    private Long id;

    @Excel(name = "报表编号")
    @ApiModelProperty("报表ID")
    private Long reportId;

    @ApiModelProperty("工序ID")
    @NotNull(message = "工序不允许为空")
    private Long priceId;

    @Excel(name = "良品数")
    @ApiModelProperty("良品数")
    @NotNull(message = "良品数不允许为空")
    @Min(value = 0, message = "良品数不允许小于0")
    private BigDecimal num;

    @Excel(name = "不良品数")
    @ApiModelProperty("不良品数")
    @NotNull(message = "不良品数不允许为空")
    @Min(value = 0, message = "不良品数不允许小于0")
    private BigDecimal defectNum;

    @Excel(name = "类别")
    @ApiModelProperty("工序类别")
    private String priceCategory;

    @Excel(name = "大小")
    @ApiModelProperty("工序大小")
    private String priceSize;

    @Excel(name = "工序")
    @ApiModelProperty("工序名称")
    private String priceName;

    @Excel(name = "子工序")
    @ApiModelProperty("子工序名称")
    private String priceSubName;

    @Excel(name = "图案")
    @ApiModelProperty("工序图案")
    private String pricePattern;

    @Excel(name = "规格")
    @ApiModelProperty("工序规格")
    private String priceSpec;

    @Excel(name = "单价(元)")
    @ApiModelProperty("工序单价(元)")
    private BigDecimal pricePrice;

    @Excel(name = "单位")
    @ApiModelProperty("工序单位")
    private String priceUnit;

    @Excel(name = "分类")
    @ApiModelProperty("工序分类")
    private String priceClassify;

    @ApiModelProperty("工序生产数量倍数分子(个)")
    private BigDecimal priceQuantityNumerator;

    @ApiModelProperty("工序生产数量倍数分母(个)")
    private BigDecimal priceQuantityDenominator;

    @Excel(name = "工序类型", dictType = DictType.PRICE_TYPE)
    @ApiModelProperty("工序类型")
    @NotBlank(message = "工序类型不允许为空")
    @DictValid(type = DictType.PRICE_TYPE, message = "非法的工序类型")
    private String priceType;

    @Size(max = 200, message = "备注长度不允许超过200个字符")
    private String remark;
}
